package Pcore::SQLite v0.10.1;

use Pcore -dist;

1;
__END__
=pod

=encoding utf8

=head1 NAME

Pcore::SQLite

=head1 SYNOPSIS

    # create database
    my $dbh = P->handle('sqlite:/path/to/db.sqlite');

    # create memory databse
    my $dbh = P->handle('sqlite:');

=head1 DESCRIPTION

=head1 FAQ

SQLite will NOT use the second column of an index if the first column was an inequality expression (eg. customer > 33).

If you create two separate indices, only one of them will be used, the other expression will be evaluated on the result set generated by the first. (on an Oracle, it could execute the two index search and intersect the result sets, if optimization is cost based and certain criteria meets, but thats a rare case).

=head1 SEE ALSO

=head1 AUTHOR

zdm <zdm@cpan.org>

=head1 CONTRIBUTORS

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by zdm.

=cut
